@@ -173,7 +173,7 @@ Convert a quantity `q` with base SI units to the symbolic units of `qout`, for `
 Mathematically, the result has value `q / uexpand(qout)` and units `dimension(qout)`.
 
 You can also use `|>` as a shorthand for `uconvert`:
-```julia
+```jldoctest
 julia> q = 1u"m/s^2" |> us"km/h^2"
 12960.0 km h⁻²
 ```
